@@ -22,8 +22,15 @@ def get_main_parser():
     def formatter(prog):
         return argparse.HelpFormatter(prog, max_help_position=25)
 
-    parser = argparse.ArgumentParser(formatter_class=formatter)
-    shtab.add_argument_to(parser, ['-s', '--print-completion'])  # magic!
+    parser = argparse.ArgumentParser(
+        formatter_class=formatter,
+        description='Use "%(prog)s command_name --help" to get detailed help to a specific command',
+    )
+    for grp in parser._action_groups:
+        if grp.title == 'options':
+            grp.title = 'Options'
+        elif grp.title == 'positional arguments':
+            grp.title = 'Commands'
 
     parser.add_argument(
         '-v',
@@ -32,36 +39,49 @@ def get_main_parser():
         choices=['warning', 'info', 'debug'],
         default='info',
     )
-    parser.add_argument('--applogin', help='Use app login instead of  web login', action='store_true')
     parser.add_argument('-V', '--version', help='Print version information and quit', action='store_true')
     parser_cmd = parser.add_subparsers(help='Desired action to perform', dest='command')
 
     # help
-    parser_cmd.add_parser('help', help='Print this help message')
+    parser_cmd.add_parser('help', help='Print this help message', description='Print help message', add_help=False)
 
     # Create parent subparser with common login arguments
     parser_login_args = argparse.ArgumentParser(add_help=False)
+    parser_login_args.add_argument('--applogin', help='Use app login instead of  web login', action='store_true')
     parser_login_args.add_argument('-n', '--phone_no', help='TradeRepbulic phone number (international format)')
     parser_login_args.add_argument('-p', '--pin', help='TradeRepbulic pin')
 
     # login
-    parser_login = parser_cmd.add_parser(
-        'login',
-        parents=[parser_login_args],
-        help='Check if credentials file exists. If not create it and ask for input.'
-        + ' Try to login. Ask for device reset if needed',
+    info = (
+        'Check if credentials file exists. If not create it and ask for input. Try to login.'
+        + ' Ask for device reset if needed'
     )
+    parser_cmd.add_parser(
+        'login',
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+        parents=[parser_login_args],
+        help=info,
+        description=info,
+    )
+
     # dl_docs
+    info = (
+        'Download all pdf documents from the timeline and sort them into folders.'
+        + ' Also export account transactions (account_transactions.csv)'
+        + ' and JSON files with all events (events_with_documents.json and other_events.json'
+    )
     parser_dl_docs = parser_cmd.add_parser(
         'dl_docs',
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
         parents=[parser_login_args],
-        help='Download all pdf documents from the timeline and sort them into folders',
+        help=info,
+        description=info,
     )
+
     parser_dl_docs.add_argument('output', help='Output directory', metavar='PATH', type=Path)
     parser_dl_docs.add_argument(
         '--format',
-        help='available variables:\tiso_date, time, title, doc_num, subtitle',
+        help='available variables:\tiso_date, time, title, doc_num, subtitle, id',
         metavar='FORMAT_STRING',
         default='{iso_date}{time} {title}{doc_num}',
     )
@@ -72,31 +92,52 @@ def get_main_parser():
         '--workers', help='Number of workers for parallel downloading', metavar='WORKERS', default=8, type=int
     )
     # portfolio
-    parser_cmd.add_parser('portfolio', parents=[parser_login_args], help='Show current portfolio')
-    parser_details = parser_cmd.add_parser('details', parents=[parser_login_args], help='Get details for an ISIN')
+    info = 'Show current portfolio'
+    parser_cmd.add_parser(
+        'portfolio',
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+        parents=[parser_login_args],
+        help=info,
+        description=info,
+    )
     # details
+    info = 'Get details for an ISIN'
+    parser_details = parser_cmd.add_parser(
+        'details',
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+        parents=[parser_login_args],
+        help=info,
+        description=info,
+    )
     parser_details.add_argument('isin', help='ISIN of intrument')
     # get_price_alarms
-    parser_get_price_alarms = parser_cmd.add_parser(
+    info = 'Get overview of current price alarms'
+    parser_cmd.add_parser(
         'get_price_alarms',
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
         parents=[parser_login_args],
-        help='Get overview of current price alarms',
+        help=info,
+        description=info,
     )
     # set_price_alarms
+    info = 'Set price alarms based on diff from current price'
     parser_set_price_alarms = parser_cmd.add_parser(
         'set_price_alarms',
-        parents=[parser_login_args],
-        help='Set price alarms based on diff from current price',
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+        parents=[parser_login_args],
+        help=info,
+        description=info,
     )
     parser_set_price_alarms.add_argument(
         '-%', '--percent', help='Percentage +/-', metavar='[-1000 ... 1000]', type=int, default=-10
     )
     # export_transactions
+    info = 'Create a CSV with the deposits and removals ready for importing into Portfolio Performance'
     parser_export_transactions = parser_cmd.add_parser(
         'export_transactions',
-        help='Create a CSV with the deposits and removals ready for importing into Portfolio Performance',
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+        help=info,
+        description=info,
     )
     parser_export_transactions.add_argument(
         'input', help='Input path to JSON (use other_events.json from dl_docs)', metavar='INPUT', type=Path
@@ -106,6 +147,11 @@ def get_main_parser():
         '-l', '--lang', help='Two letter language code or "auto" for system language', default='auto'
     )
 
+    info = 'Print shell tab completion'
+    parser_completion = parser_cmd.add_parser(
+        'completion', formatter_class=argparse.ArgumentDefaultsHelpFormatter, help=info, description=info
+    )
+    shtab.add_argument_to(parser_completion, "shell", parent=parser)
     return parser
 
 
@@ -140,10 +186,9 @@ def main():
     log = get_logger(__name__, args.verbosity)
     log.setLevel(args.verbosity.upper())
     log.debug('logging is set to debug')
-    weblogin = not args.applogin
 
     if args.command == 'login':
-        login(phone_no=args.phone_no, pin=args.pin, web=weblogin)
+        login(phone_no=args.phone_no, pin=args.pin, web=not args.applogin)
 
     elif args.command == 'dl_docs':
         if args.last_days == 0:
@@ -152,7 +197,7 @@ def main():
             since_timestamp = (time.time() - (24 * 3600 * args.last_days)) * 1000
 
         dl = DL(
-            login(phone_no=args.phone_no, pin=args.pin, web=weblogin),
+            login(phone_no=args.phone_no, pin=args.pin, web=not args.applogin),
             args.output,
             args.format,
             since_timestamp=since_timestamp,
@@ -163,11 +208,11 @@ def main():
         # TODO
         print('Not implemented yet')
     elif args.command == 'get_price_alarms':
-        Alarms(login(phone_no=args.phone_no, pin=args.pin, web=weblogin)).get()
+        Alarms(login(phone_no=args.phone_no, pin=args.pin, web=not args.applogin)).get()
     elif args.command == 'details':
-        Details(login(phone_no=args.phone_no, pin=args.pin, web=weblogin), args.isin).get()
+        Details(login(phone_no=args.phone_no, pin=args.pin, web=not args.applogin), args.isin).get()
     elif args.command == 'portfolio':
-        Portfolio(login(phone_no=args.phone_no, pin=args.pin, web=weblogin)).get()
+        Portfolio(login(phone_no=args.phone_no, pin=args.pin, web=not args.applogin)).get()
     elif args.command == 'export_transactions':
         export_transactions(args.input, args.output, args.lang)
     elif args.version:
